@@ -68,15 +68,19 @@ class StateConfig(configparser.ConfigParser):
         else:
             self.qt_version_changed = False
 
-        for sect in ['general', 'geometry']:
+        for sect in ['general', 'geometry', 'inspector']:
             try:
                 self.add_section(sect)
             except configparser.DuplicateSectionError:
                 pass
 
-        deleted_keys = ['fooled', 'backend-warning-shown']
-        for key in deleted_keys:
-            self['general'].pop(key, None)
+        deleted_keys = [
+            ('general', 'fooled'),
+            ('general', 'backend-warning-shown'),
+            ('geometry', 'inspector'),
+        ]
+        for sect, key in deleted_keys:
+            self[sect].pop(key, None)
 
         self['general']['qt_version'] = qt_version
         self['general']['version'] = qutebrowser.__version__
@@ -319,7 +323,7 @@ class YamlMigrations(QObject):
         self._migrate_font_replacements()
 
         self._migrate_bool('tabs.favicons.show', 'always', 'never')
-        self._migrate_bool('scrolling.bar', 'always', 'when-searching')
+        self._migrate_bool('scrolling.bar', 'always', 'overlay')
         self._migrate_bool('qt.force_software_rendering',
                            'software-opengl', 'none')
         self._migrate_renamed_bool(
@@ -332,6 +336,11 @@ class YamlMigrations(QObject):
             new_name='tabs.mode_on_change',
             true_value='persist',
             false_value='normal')
+        self._migrate_renamed_bool(
+            old_name='statusbar.hide',
+            new_name='statusbar.show',
+            true_value='never',
+            false_value='always')
 
         for setting in ['tabs.title.format',
                         'tabs.title.format_pinned',
@@ -340,6 +349,10 @@ class YamlMigrations(QObject):
                                        r'(?<!{)\{title\}(?!})',
                                        r'{current_title}')
 
+        self._migrate_to_multiple('fonts.tabs',
+                                  ('fonts.tabs.selected',
+                                   'fonts.tabs.unselected'))
+
         # content.headers.user_agent can't be empty to get the default anymore.
         setting = 'content.headers.user_agent'
         self._migrate_none(setting, configdata.DATA[setting].default)
@@ -446,6 +459,19 @@ class YamlMigrations(QObject):
                 self._settings[name][scope] = value
                 self.changed.emit()
 
+    def _migrate_to_multiple(self, old_name: str,
+                             new_names: typing.Iterable[str]) -> None:
+        if old_name not in self._settings:
+            return
+
+        for new_name in new_names:
+            self._settings[new_name] = {}
+            for scope, val in self._settings[old_name].items():
+                self._settings[new_name][scope] = val
+
+        del self._settings[old_name]
+        self.changed.emit()
+
     def _migrate_string_value(self, name: str,
                               source: str,
                               target: str) -> None:
@@ -603,6 +629,17 @@ class ConfigPyWriter:
     def _gen_header(self) -> typing.Iterator[str]:
         """Generate the initial header of the config."""
         yield self._line("# Autogenerated config.py")
+        yield self._line("#")
+
+        note = ("NOTE: config.py is intended for advanced users who are "
+                "comfortable with manually migrating the config file on "
+                "qutebrowser upgrades. If you prefer, you can also configure "
+                "qutebrowser using the :set/:bind/:config-* commands without "
+                "having to write a config.py file.")
+        for line in textwrap.wrap(note):
+            yield self._line("# {}".format(line))
+
+        yield self._line("#")
         yield self._line("# Documentation:")
         yield self._line("#   qute://help/configuring.html")
         yield self._line("#   qute://help/settings.html")
