@@ -83,6 +83,8 @@ def autoconfig(config_tmpdir):
      'version = 1.2.3\n'
      '\n'
      '[geometry]\n'
+     '\n'
+     '[inspector]\n'
      '\n'),
     ('[general]\n'
      'fooled = true',
@@ -92,6 +94,8 @@ def autoconfig(config_tmpdir):
      'version = 1.2.3\n'
      '\n'
      '[geometry]\n'
+     '\n'
+     '[inspector]\n'
      '\n'),
     ('[general]\n'
      'foobar = 42',
@@ -102,6 +106,8 @@ def autoconfig(config_tmpdir):
      'version = 1.2.3\n'
      '\n'
      '[geometry]\n'
+     '\n'
+     '[inspector]\n'
      '\n'),
     (None,
      True,
@@ -111,6 +117,8 @@ def autoconfig(config_tmpdir):
      'newval = 23\n'
      '\n'
      '[geometry]\n'
+     '\n'
+     '[inspector]\n'
      '\n'),
 ])
 def test_state_config(fake_save_manager, data_tmpdir, monkeypatch,
@@ -501,7 +509,7 @@ class TestYamlMigrations:
         ('tabs.favicons.show', 'always', 'always'),
 
         ('scrolling.bar', True, 'always'),
-        ('scrolling.bar', False, 'when-searching'),
+        ('scrolling.bar', False, 'overlay'),
         ('scrolling.bar', 'always', 'always'),
 
         ('qt.force_software_rendering', True, 'software-opengl'),
@@ -578,8 +586,6 @@ class TestYamlMigrations:
     @pytest.mark.parametrize('setting, old, new', [
         # Font
         ('fonts.hints', '10pt monospace', '10pt default_family'),
-        # QtFont
-        ('fonts.debug_console', '10pt monospace', '10pt default_family'),
         # String
         ('content.headers.accept_language', 'x monospace', 'x monospace'),
         # Not at end of string
@@ -588,6 +594,17 @@ class TestYamlMigrations:
     def test_font_replacements(self, migration_test, setting, old, new):
         migration_test(setting, old, new)
 
+    def test_fonts_tabs(self, yaml, autoconfig):
+        val = '10pt default_family'
+        autoconfig.write({'fonts.tabs': {'global': val}})
+
+        yaml.load()
+        yaml._save()
+
+        data = autoconfig.read()
+        assert data['fonts.tabs.unselected']['global'] == val
+        assert data['fonts.tabs.selected']['global'] == val
+
 
 class ConfPy:
 
@@ -1052,6 +1069,13 @@ class TestConfigPyWriter:
 
         assert text == textwrap.dedent("""
             # Autogenerated config.py
+            #
+            # NOTE: config.py is intended for advanced users who are comfortable
+            # with manually migrating the config file on qutebrowser upgrades. If
+            # you prefer, you can also configure qutebrowser using the
+            # :set/:bind/:config-* commands without having to write a config.py
+            # file.
+            #
             # Documentation:
             #   qute://help/configuring.html
             #   qute://help/settings.html
@@ -1156,17 +1180,10 @@ class TestConfigPyWriter:
     def test_empty(self):
         writer = configfiles.ConfigPyWriter(options=[], bindings={},
                                             commented=False)
-        text = '\n'.join(writer._gen_lines())
-        expected = textwrap.dedent("""
-            # Autogenerated config.py
-            # Documentation:
-            #   qute://help/configuring.html
-            #   qute://help/settings.html
-
-            # Uncomment this to still load settings configured via autoconfig.yml
-            # config.load_autoconfig()
-        """).lstrip()
-        assert text == expected
+        lines = list(writer._gen_lines())
+        assert lines[0] == '# Autogenerated config.py'
+        assert lines[-2] == '# config.load_autoconfig()'
+        assert not lines[-1]
 
     def test_pattern(self):
         opt = configdata.Option(
